@@ -1,30 +1,35 @@
 var group__pw__proxy =
 [
+    [ "proxy.h", "proxy_8h.html", null ],
     [ "pw_proxy_events", "structpw__proxy__events.html", [
-      [ "bound", "structpw__proxy__events.html#a8916a9be2fa3763221fdf64f79468d14", null ],
+      [ "version", "structpw__proxy__events.html#a25e8553fd0ed2f729ffe61994f6973a2", null ],
       [ "destroy", "structpw__proxy__events.html#aaa8802aa5a62fdc422f8db0d606adac3", null ],
-      [ "done", "structpw__proxy__events.html#a1d91d77027018205abcdfe5f25b0feb1", null ],
-      [ "error", "structpw__proxy__events.html#af8e0510a58d92ddd0831293e1c42b867", null ],
+      [ "bound", "structpw__proxy__events.html#a8916a9be2fa3763221fdf64f79468d14", null ],
       [ "removed", "structpw__proxy__events.html#a8072b9d1ea7e1c91cce89de75d1c7e61", null ],
-      [ "version", "structpw__proxy__events.html#a25e8553fd0ed2f729ffe61994f6973a2", null ]
+      [ "done", "structpw__proxy__events.html#a1d91d77027018205abcdfe5f25b0feb1", null ],
+      [ "error", "structpw__proxy__events.html#af8e0510a58d92ddd0831293e1c42b867", null ]
     ] ],
+    [ "pw_proxy", "structpw__proxy.html", null ],
+    [ "PW_VERSION_PROXY_EVENTS", "group__pw__proxy.html#ga8dd7c3044529e15a8fcc8c1034bbb102", null ],
+    [ "pw_proxy_notify", "group__pw__proxy.html#ga8f5ec1968479b4955dbb6988e12fc130", null ],
     [ "pw_proxy_call", "group__pw__proxy.html#ga0cb18a01022f447b12c4fd0b9d0155cb", null ],
     [ "pw_proxy_call_res", "group__pw__proxy.html#gaa93c46b89222bd416df4f4c058f89c21", null ],
-    [ "pw_proxy_notify", "group__pw__proxy.html#ga8f5ec1968479b4955dbb6988e12fc130", null ],
+    [ "pw_proxy_new", "group__pw__proxy.html#ga180c3e80b14241f3a3a790131db5b42f", null ],
     [ "pw_proxy_add_listener", "group__pw__proxy.html#ga01735abb03506ca5b939744c2679e8ae", null ],
     [ "pw_proxy_add_object_listener", "group__pw__proxy.html#ga145c4c84bc198084c219d56c352dafb7", null ],
     [ "pw_proxy_destroy", "group__pw__proxy.html#gadb7836fa36fc664449def4b9ea27c7ed", null ],
+    [ "pw_proxy_ref", "group__pw__proxy.html#gacae5a1b85f78c3a018d1e773dcc44372", null ],
+    [ "pw_proxy_unref", "group__pw__proxy.html#ga250ab0018692b3340ff83591e24b72cf", null ],
+    [ "pw_proxy_get_user_data", "group__pw__proxy.html#ga0b7f4a63edcc2f05d15944891d4e62f1", null ],
+    [ "pw_proxy_get_id", "group__pw__proxy.html#gaa4790d3d0254680598e0c9a19f9107a3", null ],
+    [ "pw_proxy_get_type", "group__pw__proxy.html#ga0f71823c5820bed86a1ad3e4e7f6848d", null ],
+    [ "pw_proxy_get_protocol", "group__pw__proxy.html#ga84c0fa652d3df07f13a0e32cd270674f", null ],
+    [ "pw_proxy_sync", "group__pw__proxy.html#ga9490301016b057af0551c759696c374c", null ],
+    [ "pw_proxy_set_bound_id", "group__pw__proxy.html#ga00ecf59a7b69d43ae4106312174d709b", null ],
+    [ "pw_proxy_get_bound_id", "group__pw__proxy.html#ga68572822ba2f4e2160e81c4f892ac346", null ],
     [ "pw_proxy_error", "group__pw__proxy.html#ga5a1ea70103be68200f15ceff8c89f7bc", null ],
     [ "pw_proxy_errorf", "group__pw__proxy.html#gacb4cff3a2f5d8a19cad33e811fc6de26", null ],
-    [ "pw_proxy_get_bound_id", "group__pw__proxy.html#ga68572822ba2f4e2160e81c4f892ac346", null ],
-    [ "pw_proxy_get_id", "group__pw__proxy.html#gaa4790d3d0254680598e0c9a19f9107a3", null ],
-    [ "pw_proxy_get_marshal", "group__pw__proxy.html#ga0ab131fa8d39c202c9235a40f64b188e", null ],
     [ "pw_proxy_get_object_listeners", "group__pw__proxy.html#gab71faf90806664872fb77590fb48d28b", null ],
-    [ "pw_proxy_get_protocol", "group__pw__proxy.html#ga84c0fa652d3df07f13a0e32cd270674f", null ],
-    [ "pw_proxy_get_type", "group__pw__proxy.html#ga0f71823c5820bed86a1ad3e4e7f6848d", null ],
-    [ "pw_proxy_get_user_data", "group__pw__proxy.html#ga0b7f4a63edcc2f05d15944891d4e62f1", null ],
-    [ "pw_proxy_install_marshal", "group__pw__proxy.html#gad3231c616d6b193d24d3bd0895670daf", null ],
-    [ "pw_proxy_new", "group__pw__proxy.html#ga180c3e80b14241f3a3a790131db5b42f", null ],
-    [ "pw_proxy_set_bound_id", "group__pw__proxy.html#ga00ecf59a7b69d43ae4106312174d709b", null ],
-    [ "pw_proxy_sync", "group__pw__proxy.html#ga9490301016b057af0551c759696c374c", null ]
+    [ "pw_proxy_get_marshal", "group__pw__proxy.html#ga0ab131fa8d39c202c9235a40f64b188e", null ],
+    [ "pw_proxy_install_marshal", "group__pw__proxy.html#gad3231c616d6b193d24d3bd0895670daf", null ]
 ];
\ No newline at end of file
