@@ -1,5 +1,22 @@
 var NAVTREEINDEX17 =
 {
+"page_man_pipewire_pulse_1.html":[5,12,1],
+"page_man_pw_cat_1.html":[5,12,3],
+"page_man_pw_cli_1.html":[5,12,4],
+"page_man_pw_dot_1.html":[5,12,5],
+"page_man_pw_jack_1.html":[5,12,12],
+"page_man_pw_link_1.html":[5,12,6],
+"page_man_pw_metadata_1.html":[5,12,7],
+"page_man_pw_mididump_1.html":[5,12,8],
+"page_man_pw_mon_1.html":[5,12,9],
+"page_man_pw_profiler_1.html":[5,12,10],
+"page_man_pw_top_1.html":[5,12,11],
+"page_midi.html":[5,7],
+"page_midi.html#autotoc_md20":[5,7,0],
+"page_midi.html#autotoc_md21":[5,7,0,0],
+"page_midi.html#autotoc_md22":[5,7,0,1],
+"page_midi.html#autotoc_md23":[5,7,0,2],
+"page_midi.html#autotoc_md24":[5,7,0,3],
 "page_midi.html#autotoc_md25":[5,7,0,4],
 "page_midi.html#autotoc_md26":[5,7,1],
 "page_midi.html#autotoc_md27":[5,7,1,0],
@@ -232,22 +249,5 @@ var NAVTREEINDEX17 =
 "structpw__client__node__events.html":[10,7,0,2],
 "structpw__client__node__events.html#a0942c754a0fd77db7c9051172b2ac991":[10,7,0,2,10],
 "structpw__client__node__events.html#a0fdb140f41117e7690aca449844d72c2":[10,7,0,2,9],
-"structpw__client__node__events.html#a3802ec24f1305664c8d1b846abc244c8":[10,7,0,2,7],
-"structpw__client__node__events.html#a3d12bf0a63aba14bc897e4ceb51e4fe4":[10,7,0,2,0],
-"structpw__client__node__events.html#a63c10e914836b4c4ffc02be889c717f8":[10,7,0,2,8],
-"structpw__client__node__events.html#a775ca4ec6d6115039b2e8574bef184f2":[10,7,0,2,4],
-"structpw__client__node__events.html#aa25eeb692995699b672f71251ec0b4b6":[10,7,0,2,11],
-"structpw__client__node__events.html#ab1aba9806056fc945c2328f1cc128f6e":[10,7,0,2,12],
-"structpw__client__node__events.html#abac4b80ae987a95a81ece32baa8fef14":[10,7,0,2,5],
-"structpw__client__node__events.html#abb5194c288d8bb436b1c8264e21037c7":[10,7,0,2,3],
-"structpw__client__node__events.html#ac0b5a3c66103be01b784464d4dd81fa0":[10,7,0,2,6],
-"structpw__client__node__events.html#ac5884f60926b382728097c8846dcba85":[10,7,0,2,2],
-"structpw__client__node__events.html#ad7084094ae633b01409033ba363ef78b":[10,7,0,2,1],
-"structpw__client__node__methods.html":[10,7,0,3],
-"structpw__client__node__methods.html#a0193c45d32cc6806d8b1f4ef9c7a2740":[10,7,0,3,6],
-"structpw__client__node__methods.html#a05968e322e128af7d58f1598ad61af7e":[10,7,0,3,1],
-"structpw__client__node__methods.html#a0d45045558276d9594008b5ac39ad404":[10,7,0,3,2],
-"structpw__client__node__methods.html#a1db43e226468e68a6a52292aa6a894c6":[10,7,0,3,7],
-"structpw__client__node__methods.html#acf64a3bd71fd790592e41458a4793c62":[10,7,0,3,0],
-"structpw__client__node__methods.html#ae7a71dd91cda53767aa31aa10c050244":[10,7,0,3,5]
+"structpw__client__node__events.html#a3802ec24f1305664c8d1b846abc244c8":[10,7,0,2,7]
 };
