@@ -1,5 +1,9 @@
 var NAVTREEINDEX19 =
 {
+"structpw__impl__node__events.html#a0c45913c502536b96684e02449475a18":[10,5,7,1,16],
+"structpw__impl__node__events.html#a16b71cb7eece2a1b7b2d89007357238b":[10,5,7,1,10],
+"structpw__impl__node__events.html#a21b4486448a26b56eea0508a92c99035":[10,5,7,1,1],
+"structpw__impl__node__events.html#a347372b746a4f05fc0a6d8ecb1346dd6":[10,5,7,1,4],
 "structpw__impl__node__events.html#a4364b27231c433313991f473948e5e3f":[10,5,7,1,15],
 "structpw__impl__node__events.html#a5b8cbba5cb1b1d8574929dc73a915463":[10,5,7,1,12],
 "structpw__impl__node__events.html#a5ec09d921107cfaec7a569d07d7c1430":[10,5,7,1,0],
@@ -13,9 +17,9 @@ var NAVTREEINDEX19 =
 "structpw__impl__node__events.html#abae73b060850e69368efdace5e1ddd68":[10,5,7,1,3],
 "structpw__impl__node__events.html#ac82d3cde1bc6a6b7a617f80b74c8dc9e":[10,5,7,1,14],
 "structpw__impl__node__events.html#adbaa329398d27871d25ddacad8a33c12":[10,5,7,1,11],
+"structpw__impl__port.html":[10,5,4,3],
 "structpw__impl__port.html":[10,5,7,3],
 "structpw__impl__port.html":[10,5,8,2],
-"structpw__impl__port.html":[10,5,4,3],
 "structpw__impl__port__events.html":[10,5,8,1],
 "structpw__impl__port__events.html#a3e2788e02240c77076c32642e1d57c82":[10,5,8,1,8],
 "structpw__impl__port__events.html#a5595c734ed5c3fc9ab27c2f5244fa325":[10,5,8,1,1],
@@ -245,9 +249,5 @@ var NAVTREEINDEX19 =
 "structpw__session__info.html#a00aaf0720fd58ae285a1fe122ab0fb93":[10,7,4,18,3],
 "structpw__session__info.html#a1289ec21ec9441f29314a561b341cf13":[10,7,4,18,2],
 "structpw__session__info.html#aa2d06aa8a36c3da1890e37f02e4702a6":[10,7,4,18,1],
-"structpw__session__info.html#aa58e4f042f5cf3226d0765654439a9a3":[10,7,4,18,0],
-"structpw__session__info.html#abfebf0a6ad9331c4690ffad37894d660":[10,7,4,18,4],
-"structpw__session__methods.html":[10,7,4,11],
-"structpw__session__methods.html#a39a82c063c97d967e5ee82589c390c29":[10,7,4,11,0],
-"structpw__session__methods.html#a66e604601841f9f2252db7c4a4466f6f":[10,7,4,11,4]
+"structpw__session__info.html#aa58e4f042f5cf3226d0765654439a9a3":[10,7,4,18,0]
 };
