@@ -1,5 +1,7 @@
 var NAVTREEINDEX7 =
 {
+"group__pw__session__manager.html#ga9c189d1f82467baaf78c4863c8320b3c":[10,7,4,36],
+"group__pw__session__manager.html#ga9c5fa0d0f2d2f18e9107ba5dd49b15c2":[10,7,4,165],
 "group__pw__session__manager.html#ga9ce6b085d6110a166e03135e3977c7f2":[10,7,4,133],
 "group__pw__session__manager.html#ga9e7a7a0f7a48b2f6afc5b34cd488695a":[10,7,4,112],
 "group__pw__session__manager.html#ga9ea9d15f9c2b54a69cd4b27f5f300b99":[10,7,4,42],
@@ -247,7 +249,5 @@ var NAVTREEINDEX7 =
 "group__spa__ansi.html#ga4921f428347162b6e1afd0d5362370ec":[10,8,8,0,18],
 "group__spa__ansi.html#ga4e4c73b12e79a492d93d1697cb8d48bb":[10,8,8,0,49],
 "group__spa__ansi.html#ga5107dd7b42a3abdcd2cbf1623f5a76af":[10,8,8,0,30],
-"group__spa__ansi.html#ga54d15ab61e76cc597c18301ff384435e":[10,8,8,0,1],
-"group__spa__ansi.html#ga5d126113edfe9df70eb7f68a6f874c85":[10,8,8,0,31],
-"group__spa__ansi.html#ga5dafdd57666d36a3a23172b309e5e2d8":[10,8,8,0,42]
+"group__spa__ansi.html#ga54d15ab61e76cc597c18301ff384435e":[10,8,8,0,1]
 };
