@@ -1,5 +1,12 @@
 var NAVTREEINDEX8 =
 {
+"group__spa__ansi.html#ga5d126113edfe9df70eb7f68a6f874c85":[10,8,8,0,31],
+"group__spa__ansi.html#ga5dafdd57666d36a3a23172b309e5e2d8":[10,8,8,0,42],
+"group__spa__ansi.html#ga678d0b293b16e0d6a1fe0acef4915d58":[10,8,8,0,38],
+"group__spa__ansi.html#ga67b64705e0973206f62671580235ad91":[10,8,8,0,36],
+"group__spa__ansi.html#ga7e7da142af610c73f650312677383d99":[10,8,8,0,13],
+"group__spa__ansi.html#ga81bfa95fac68a133fd545e7fa4e9d1d1":[10,8,8,0,5],
+"group__spa__ansi.html#ga82142b091ace82f6742527d72cb3a9e4":[10,8,8,0,52],
 "group__spa__ansi.html#ga8b943fd646e64cbd0fa60484a0900d94":[10,8,8,0,19],
 "group__spa__ansi.html#ga8dcc1e4283933e216eca2305dda3ccf6":[10,8,8,0,12],
 "group__spa__ansi.html#ga9691e3321fd9a291860a04b0d219d52f":[10,8,8,0,41],
@@ -242,12 +249,5 @@ var NAVTREEINDEX8 =
 "group__spa__device.html#ga9041192b59420c24635c77848b5ab7d5":[10,8,4,11],
 "group__spa__device.html#ga951b6e27cbc5b868672a87b8c9b5d818":[10,8,4,43],
 "group__spa__device.html#ga956329c75f9076a9de5a2ee8f9cefed3":[10,8,4,30],
-"group__spa__device.html#ga956f53165732be66eff3cd772e80b7cf":[10,8,4,46],
-"group__spa__device.html#ga976176b17916248c604ae02498d9f648":[10,8,4,65],
-"group__spa__device.html#ga9bf1b22af1de0ff91ebb45df40d82645":[10,8,4,34],
-"group__spa__device.html#ga9f19955c5b6a77028eb697a130a5f22e":[10,8,4,47],
-"group__spa__device.html#ga9fc516e68fefb9e3c7f08a5fa4ac8242":[10,8,4,22],
-"group__spa__device.html#gaa6141368f70a58863efc5494673903ba":[10,8,4,33],
-"group__spa__device.html#gaa8e69a2fae59e8d6d1d1da5f0660cbc3":[10,8,4,13],
-"group__spa__device.html#gab347a871f54232e2f8362c60fd893128":[10,8,4,21]
+"group__spa__device.html#ga956f53165732be66eff3cd772e80b7cf":[10,8,4,46]
 };
